@@ -1,9 +1,18 @@
-from typing import Any, Callable, List, Mapping, Type, Coroutine, Optional
+from typing import (
+    Any,
+    Callable,
+    List,
+    Mapping,
+    Type,
+    Coroutine,
+    Optional,
+    Union,
+)
 
 from fastapi import HTTPException
 
 from . import CRUDGenerator, NOT_FOUND, _utils
-from ._types import PAGINATION, PYDANTIC_SCHEMA
+from ._types import PAGINATION, PYDANTIC_SCHEMA, DEPENDENCIES
 
 try:
     from sqlalchemy.sql.schema import Table
@@ -29,12 +38,12 @@ class DatabasesCRUDRouter(CRUDGenerator[PYDANTIC_SCHEMA]):
         prefix: Optional[str] = None,
         tags: Optional[List[str]] = None,
         paginate: Optional[int] = None,
-        get_all_route: bool = True,
-        get_one_route: bool = True,
-        create_route: bool = True,
-        update_route: bool = True,
-        delete_one_route: bool = True,
-        delete_all_route: bool = True,
+        get_all_route: Union[bool, DEPENDENCIES] = True,
+        get_one_route: Union[bool, DEPENDENCIES] = True,
+        create_route: Union[bool, DEPENDENCIES] = True,
+        update_route: Union[bool, DEPENDENCIES] = True,
+        delete_one_route: Union[bool, DEPENDENCIES] = True,
+        delete_all_route: Union[bool, DEPENDENCIES] = True,
         **kwargs: Any
     ) -> None:
         assert (
