@@ -6,12 +6,13 @@ from typing import (
     Type,
     cast,
     Coroutine,
+    Union,
 )
 
 from fastapi import HTTPException
 
 from . import CRUDGenerator, NOT_FOUND, _utils
-from ._types import PAGINATION
+from ._types import DEPENDENCIES, PAGINATION
 
 try:
     from ormar import Model, NoMatch
@@ -34,12 +35,12 @@ class OrmarCRUDRouter(CRUDGenerator[Model]):
         prefix: Optional[str] = None,
         tags: Optional[List[str]] = None,
         paginate: Optional[int] = None,
-        get_all_route: bool = True,
-        get_one_route: bool = True,
-        create_route: bool = True,
-        update_route: bool = True,
-        delete_one_route: bool = True,
-        delete_all_route: bool = True,
+        get_all_route: Union[bool, DEPENDENCIES] = True,
+        get_one_route: Union[bool, DEPENDENCIES] = True,
+        create_route: Union[bool, DEPENDENCIES] = True,
+        update_route: Union[bool, DEPENDENCIES] = True,
+        delete_one_route: Union[bool, DEPENDENCIES] = True,
+        delete_all_route: Union[bool, DEPENDENCIES] = True,
         **kwargs: Any
     ) -> None:
         assert ormar_installed, "Ormar must be installed to use the OrmarCRUDRouter."
