@@ -1,9 +1,9 @@
-from typing import Any, Callable, List, Type, Generator, Optional
+from typing import Any, Callable, List, Type, Generator, Optional, Union
 
 from fastapi import Depends, HTTPException
 
 from . import CRUDGenerator, NOT_FOUND, _utils
-from ._types import PAGINATION, PYDANTIC_SCHEMA as SCHEMA
+from ._types import DEPENDENCIES, PAGINATION, PYDANTIC_SCHEMA as SCHEMA
 
 try:
     from sqlalchemy.orm import Session
@@ -28,12 +28,12 @@ class SQLAlchemyCRUDRouter(CRUDGenerator[SCHEMA]):
         prefix: Optional[str] = None,
         tags: Optional[List[str]] = None,
         paginate: Optional[int] = None,
-        get_all_route: bool = True,
-        get_one_route: bool = True,
-        create_route: bool = True,
-        update_route: bool = True,
-        delete_one_route: bool = True,
-        delete_all_route: bool = True,
+        get_all_route: Union[bool, DEPENDENCIES] = True,
+        get_one_route: Union[bool, DEPENDENCIES] = True,
+        create_route: Union[bool, DEPENDENCIES] = True,
+        update_route: Union[bool, DEPENDENCIES] = True,
+        delete_one_route: Union[bool, DEPENDENCIES] = True,
+        delete_all_route: Union[bool, DEPENDENCIES] = True,
         **kwargs: Any
     ) -> None:
         assert (
